@@ -1,7 +1,7 @@
 import os
 import subprocess
 import sys
-from jobx import jobx
+from .. import jobx
 
 os.environ['ANSI_COLORS_DISABLED']="1"
 import fire
