@@ -1,6 +1,6 @@
 import importlib
 from .utils import convert_path_to_module_string,dict2obj,EasyDict
-from .builders import Builder
+from .build import build
 from .task_runner import BatchTaskRunner
 from .config import load_config, load_config_yaml
 import os
@@ -49,12 +49,13 @@ def run_tasks(task=None, **kwargs):
     )
 
     cfg = load_config_yaml(config_file, **kwargs)
-    cfg.update(default_config)
+    default_config.update(cfg)
+    cfg=EasyDict(**default_config)
 
     workers_limit = cfg.get('workers_limit', 1)
     delay = cfg.get('delay', 0)
     silent=cfg.get("silent",True)
-    tasks = Builder.build(cfg, cfg.get('name', 'Task'), task)
+    tasks = build(cfg, cfg.get('name', 'Task'), task)
     BatchTaskRunner(tasks, workers_limit, delay,silent=silent).run()
 
 
